cosmpy.protos.cosmos.auth package — cosmpy documentation

# cosmpy.protos.cosmos.auth package

## Subpackages

- cosmpy.protos.cosmos.auth.v1beta1 package
  - Submodules
  - cosmpy.protos.cosmos.auth.v1beta1.auth_pb2 module
  - cosmpy.protos.cosmos.auth.v1beta1.auth_pb2_grpc module
  - cosmpy.protos.cosmos.auth.v1beta1.genesis_pb2 module
  - cosmpy.protos.cosmos.auth.v1beta1.genesis_pb2_grpc module
  - cosmpy.protos.cosmos.auth.v1beta1.query_pb2 module
  - cosmpy.protos.cosmos.auth.v1beta1.query_pb2_grpc module
  - Module contents

## Module contents